@@ -242,7 +242,7 @@ def build_validator_module_imports(db_config: DBConfig) -> str:
     for node_config in node_configs:
         for prop_name, prop_config in node_config.basemodel_properties.items():
             from_str_import_strs.append(
-                f"from {prop_config.module_path} import {prop_config.module_name} as {prop_config.module_name}Model"
+                f"from {prop_config.module_path} import {prop_config.module_name}"
             )
     return "\n".join(sorted(list(set(from_str_import_strs))))
 
